pub struct LoopMemo {
pub branch: String,
pub head_sha: String,
pub ab_base_sha: String,
pub ahead: u32,
pub behind: u32,
}Expand description
One memoised ahead/behind entry for a branch.
Fields
branch: Stringhead_sha: StringHEAD SHA of the branch at the time of the computation.
ab_base_sha: StringHEAD SHA of the default branch at the time of the computation.
ahead: u32behind: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for LoopMemo
impl<'de> Deserialize<'de> for LoopMemo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LoopMemo
impl StructuralPartialEq for LoopMemo