pub fn scan(
roots: &[PathBuf],
labels: &[(PathBuf, String)],
scan_depth: usize,
) -> (Vec<OpenLoop>, Vec<String>)Expand description
Scans all repos found under the roots in parallel.
Individual repo failures become warnings and never abort the scan.