pub trait SessionSource {
// Required method
fn excerpts(
&self,
repo_path: &Path,
branch: &str,
window: (DateTime<Utc>, DateTime<Utc>),
max_sessions: usize,
max_kb: u64,
) -> Result<Vec<SessionExcerpt>>;
}Required Methods
Sourcefn excerpts(
&self,
repo_path: &Path,
branch: &str,
window: (DateTime<Utc>, DateTime<Utc>),
max_sessions: usize,
max_kb: u64,
) -> Result<Vec<SessionExcerpt>>
fn excerpts( &self, repo_path: &Path, branch: &str, window: (DateTime<Utc>, DateTime<Utc>), max_sessions: usize, max_kb: u64, ) -> Result<Vec<SessionExcerpt>>
Excerpts of the sessions most relevant to the branch.
window: commit time range of the branch (sessions outside it that do
not mention the branch are discarded).
Errors
Returns an error if the projects directory cannot be read.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".